@@ -1,6 +1,6 @@
 /* Dynamically allocated strings
-   Copyright (c) 2001-2004 Sandro Sigala.
-   Copyright (c) 2003-2007 Reuben Thomas.
+   Copyright (c) 2001, 2002, 2003, 2004 Sandro Sigala.
+   Copyright (c) 2003, 2004, 2005, 2006, 2007 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -50,7 +50,7 @@ typedef struct astr_s *astr;
 /*
  * Allocate a new string with zero length.
  */
-extern astr astr_new(void);
+extern astr astr_new (void);
 
 /*
  * Make a new string from a C null-terminated string
@@ -60,7 +60,7 @@ extern astr astr_new(void);
 /*
  * Deallocate the previously allocated string as.
  */
-extern void astr_delete(astr as);
+extern void astr_delete (astr as);
 
 /*
  * Convert as into a C null-terminated string.
@@ -78,13 +78,13 @@ extern void astr_delete(astr as);
  * than 0, count from the left; if less than zero count from the
  * right.
  */
-extern char *astr_char(const astr as, ptrdiff_t pos);
+extern char *astr_char (const astr as, ptrdiff_t pos);
 
 /*
  * Return a new astr consisting of size characters from string as
  * starting from position pos.
  */
-extern astr astr_substr(const astr as, ptrdiff_t pos, size_t size);
+extern astr astr_substr (const astr as, ptrdiff_t pos, size_t size);
 
 /*
  * Do strcmp on the contents of s1 and s2
@@ -95,73 +95,75 @@ extern astr astr_substr(const astr as, ptrdiff_t pos, size_t size);
 /*
  * Assign the contents of the argument string to the string as.
  */
-extern astr astr_cpy(astr as, const astr src);
-extern astr astr_cpy_cstr(astr as, const char *s);
+extern astr astr_cpy (astr as, const astr src);
+extern astr astr_cpy_cstr (astr as, const char *s);
 
 /*
  * Append the contents of the argument string or character to as.
  */
-extern astr astr_cat(astr as, const astr src);
-extern astr astr_cat_cstr(astr as, const char *s);
-extern astr astr_ncat_cstr(astr as, const char *s, size_t len);
-extern astr astr_cat_char(astr as, int c);
+extern astr astr_cat (astr as, const astr src);
+extern astr astr_cat_cstr (astr as, const char *s);
+extern astr astr_ncat_cstr (astr as, const char *s, size_t len);
+extern astr astr_cat_char (astr as, int c);
 
 /*
  * Append the contents of src to as and free src.
  */
-extern astr astr_cat_delete(astr as, const astr src);
+extern astr astr_cat_delete (astr as, const astr src);
 
 /*
  * Replace size characters of as, starting at pos, with the argument
  * string or character.
  */
-extern astr astr_replace(astr as, ptrdiff_t pos, size_t size, const astr src);
-extern astr astr_replace_cstr(astr as, ptrdiff_t pos, size_t size, const char *s);
-extern astr astr_replace_char(astr as, ptrdiff_t pos, size_t size, int c);
+extern astr astr_replace (astr as, ptrdiff_t pos, size_t size,
+			  const astr src);
+extern astr astr_replace_cstr (astr as, ptrdiff_t pos, size_t size,
+			       const char *s);
+extern astr astr_replace_char (astr as, ptrdiff_t pos, size_t size, int c);
 
 /*
  * Insert the contents of the argument string or character in as.
  */
-extern astr astr_insert(astr as, ptrdiff_t pos, const astr src);
-extern astr astr_insert_cstr(astr as, ptrdiff_t pos, const char *s);
-extern astr astr_insert_char(astr as, ptrdiff_t pos, int c);
+extern astr astr_insert (astr as, ptrdiff_t pos, const astr src);
+extern astr astr_insert_cstr (astr as, ptrdiff_t pos, const char *s);
+extern astr astr_insert_char (astr as, ptrdiff_t pos, int c);
 
 /*
  * Remove size chars from as at position pos.
  */
-extern astr astr_remove(astr as, ptrdiff_t pos, size_t size);
+extern astr astr_remove (astr as, ptrdiff_t pos, size_t size);
 
 /*
  * Truncate as to given position.
  */
-extern astr astr_truncate(astr as, ptrdiff_t pos);
+extern astr astr_truncate (astr as, ptrdiff_t pos);
 
 /*
  * Find the first occurrence of the argument string in as, returning
  * the position starting from the beginning of the string.
  */
-extern int astr_find(const astr as, const astr src);
-extern int astr_find_cstr(const astr as, const char *s);
+extern int astr_find (const astr as, const astr src);
+extern int astr_find_cstr (const astr as, const char *s);
 
 /*
  * Find the last occurrence of the argument string in as, returning
  * the position starting from the end of the string.
  */
-extern int astr_rfind(const astr as, const astr src);
-extern int astr_rfind_cstr(const astr as, const char *s);
+extern int astr_rfind (const astr as, const astr src);
+extern int astr_rfind_cstr (const astr as, const char *s);
 
 /*
  * Read a string from the stream f and return it. The trailing newline
  * is removed from the string. If the stream is at eof when astr_fgets
  * is called, it returns NULL.
  */
-extern astr astr_fgets(FILE *f);
+extern astr astr_fgets (FILE * f);
 
 /*
  * Append formatted text to the argument string
  */
-extern astr astr_vafmt(astr as, const char *fmt, va_list ap);
-extern astr astr_afmt(astr as, const char *fmt, ...);
+extern astr astr_vafmt (astr as, const char *fmt, va_list ap);
+extern astr astr_afmt (astr as, const char *fmt, ...);
 
 
 /*
@@ -174,10 +176,11 @@ extern astr astr_afmt(astr as, const char *fmt, ...);
  *
  * You should never directly access the struct fields.
  */
-struct astr_s {
-  char *  text;
-  size_t  len;
-  size_t  maxlen;
+struct astr_s
+{
+  char *text;
+  size_t len;
+  size_t maxlen;
 };
 
 
