@@ -20,35 +20,35 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: eval.h,v 1.14 2006/11/29 22:34:46 rrt Exp $	*/
-
 #ifndef EVAL_H
 #define EVAL_H
 
 #include "lists.h"
 
-typedef le *(*eval_cb)(int argc, le *branch);
-typedef struct evalLookupNode {
+typedef le *(*eval_cb) (int argc, le * branch);
+typedef struct
+{
   char *word;
   eval_cb callback;
 } evalLookupNode;
 
-eval_cb lookupFunction(char *name);
-le *evaluateBranch(le *trybranch);
-le *evaluateNode(le *node);
+eval_cb lookupFunction (char *name);
+le *evaluateBranch (le * trybranch);
+le *evaluateNode (le * node);
 
-int countNodes(le *branch);
+int countNodes (le * branch);
 
-enum setfcn {
+enum setfcn
+{
   S_SET,
   S_SETQ
 };
 
-le *eval_cb_set(int argc, le *branch);
-le *eval_cb_setq(int argc, le *branch);
+le *eval_cb_set (int argc, le * branch);
+le *eval_cb_setq (int argc, le * branch);
 
 le *leNIL, *leT;
-void eval_init(void);
-void eval_finalise(void);
+void eval_init (void);
+void eval_finalise (void);
 
 #endif
