@@ -1,5 +1,5 @@
 /* Miscellaneous functions
-   Copyright (c) 1997-2004 Sandro Sigala.  All rights reserved.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Sandro Sigala.  All rights reserved.
 
    This file is part of Zile.
 
@@ -33,13 +33,14 @@
  * Emit an error sound only when the appropriate variable
  * is set.
  */
-void ding(void)
+void
+ding (void)
 {
   if (thisflag & FLAG_DEFINING_MACRO)
-    cancel_kbd_macro();
+    cancel_kbd_macro ();
 
-  if (lookup_bool_variable("ring-bell"))
-    term_beep();
+  if (lookup_bool_variable ("ring-bell"))
+    term_beep ();
 }
 
 #define MAX_KEY_BUF	16
@@ -49,7 +50,8 @@ static int *keyp = key_buf;
 static size_t _last_key;
 
 /* Return last key pressed */
-size_t lastkey(void)
+size_t
+lastkey (void)
 {
   return _last_key;
 }
@@ -59,15 +61,16 @@ size_t lastkey(void)
  * mode contains GETKEY_DELAYED, and translating it into a
  * keycode unless mode contains GETKEY_UNFILTERED.
  */
-size_t xgetkey(int mode, size_t timeout)
+size_t
+xgetkey (int mode, size_t timeout)
 {
   if (keyp > key_buf)
     _last_key = *--keyp;
   else
-    _last_key = term_xgetkey(mode, timeout);
+    _last_key = term_xgetkey (mode, timeout);
 
   if (thisflag & FLAG_DEFINING_MACRO)
-    add_key_to_cmd(_last_key);
+    add_key_to_cmd (_last_key);
 
   return _last_key;
 }
@@ -76,21 +79,24 @@ size_t xgetkey(int mode, size_t timeout)
  * Wait for a keystroke indefinitely, and return the
  * corresponding keycode.
  */
-size_t getkey(void)
+size_t
+getkey (void)
 {
-  return xgetkey(0, 0);
+  return xgetkey (0, 0);
 }
 
 /*
  * Wait for timeout 10ths if a second or until a key is pressed.
  * The key is then available with [x]getkey().
  */
-void waitkey(size_t timeout)
+void
+waitkey (size_t timeout)
 {
-  ungetkey(xgetkey(GETKEY_DELAYED, timeout));
+  ungetkey (xgetkey (GETKEY_DELAYED, timeout));
 }
 
-void ungetkey(size_t key)
+void
+ungetkey (size_t key)
 {
   if (keyp < key_buf + MAX_KEY_BUF && key != KBD_NOKEY)
     *keyp++ = key;
@@ -99,41 +105,45 @@ void ungetkey(size_t key)
 /*
  * Copy a region of text into an allocated buffer.
  */
-char *copy_text_block(size_t startn, size_t starto, size_t size)
+char *
+copy_text_block (size_t startn, size_t starto, size_t size)
 {
   char *buf, *dp;
   size_t max_size, n, i;
   Line *lp;
 
   max_size = 10;
-  dp = buf = (char *)zmalloc(max_size);
+  dp = buf = (char *) zmalloc (max_size);
 
   lp = cur_bp->pt.p;
   n = cur_bp->pt.n;
   if (n > startn)
     do
-      lp = list_prev(lp);
+      lp = list_prev (lp);
     while (--n > startn);
   else if (n < startn)
     do
-      lp = list_next(lp);
+      lp = list_next (lp);
     while (++n < startn);
 
-  for (i = starto; dp - buf < (int)size;) {
-    if (dp >= buf + max_size) {
-      int save_off = dp - buf;
-      max_size += 10;
-      buf = (char *)zrealloc(buf, max_size);
-      dp = buf + save_off;
+  for (i = starto; dp - buf < (int) size;)
+    {
+      if (dp >= buf + max_size)
+	{
+	  int save_off = dp - buf;
+	  max_size += 10;
+	  buf = (char *) zrealloc (buf, max_size);
+	  dp = buf + save_off;
+	}
+      if (i < astr_len (lp->item))
+	*dp++ = *astr_char (lp->item, (ptrdiff_t) (i++));
+      else
+	{
+	  *dp++ = '\n';
+	  lp = list_next (lp);
+	  i = 0;
+	}
     }
-    if (i < astr_len(lp->item))
-      *dp++ = *astr_char(lp->item, (ptrdiff_t)(i++));
-    else {
-      *dp++ = '\n';
-      lp = list_next(lp);
-      i = 0;
-    }
-  }
 
   return buf;
 }
@@ -142,17 +152,19 @@ char *copy_text_block(size_t startn, size_t starto, size_t size)
  * Return a string of maximum length `maxlen' beginning with a `...'
  * sequence if a cut is need.
  */
-astr shorten_string(char *s, int maxlen)
+astr
+shorten_string (char *s, int maxlen)
 {
-  int len;
-  astr as = astr_new();
+  astr as = astr_new ();
+  int len = strlen (s);
 
-  if ((len = strlen(s)) <= maxlen)
-    astr_cpy_cstr(as, s);
-  else {
-    astr_cpy_cstr(as, "...");
-    astr_cat_cstr(as, s + len - maxlen + 3);
-  }
+  if (len <= maxlen)
+    astr_cpy_cstr (as, s);
+  else
+    {
+      astr_cpy_cstr (as, "...");
+      astr_cat_cstr (as, s + len - maxlen + 3);
+    }
 
   return as;
 }
@@ -161,17 +173,19 @@ astr shorten_string(char *s, int maxlen)
  * Replace the matches of `match' into `s' with the string `subst'.  The
  * two strings `match' and `subst' must have the same length.
  */
-char *replace_string(char *s, char *match, char *subst)
+char *
+replace_string (char *s, char *match, char *subst)
 {
   char *sp = s, *p;
-  size_t slen = strlen(subst);
+  size_t slen = strlen (subst);
 
-  if (strlen(match) != slen)
+  if (strlen (match) != slen)
     return NULL;
-  while ((p = strstr(sp, match)) != NULL) {
-    strncpy(p, subst, slen);
-    sp = p + slen;
-  }
+  while ((p = strstr (sp, match)) != NULL)
+    {
+      strncpy (p, subst, slen);
+      sp = p + slen;
+    }
 
   return s;
 }
@@ -179,38 +193,42 @@ char *replace_string(char *s, char *match, char *subst)
 /*
  * Compact the spaces into tabulations according to the `tw' tab width.
  */
-void tabify_string(char *dest, char *src, size_t scol, size_t tw)
+void
+tabify_string (char *dest, char *src, size_t scol, size_t tw)
 {
   char *sp, *dp;
   size_t dcol = scol, ocol = scol;
 
   for (sp = src, dp = dest;; ++sp)
-    switch (*sp) {
-    case ' ':
-      ++dcol;
-      break;
-    case '\t':
-      dcol += tw;
-      dcol -= dcol % tw;
-      break;
-    default:
-      while (((ocol + tw) - (ocol + tw) % tw) <= dcol) {
-        if (ocol + 1 == dcol)
-          break;
-        *dp++ = '\t';
-        ocol += tw;
-        ocol -= ocol % tw;
+    switch (*sp)
+      {
+      case ' ':
+	++dcol;
+	break;
+      case '\t':
+	dcol += tw;
+	dcol -= dcol % tw;
+	break;
+      default:
+	while (((ocol + tw) - (ocol + tw) % tw) <= dcol)
+	  {
+	    if (ocol + 1 == dcol)
+	      break;
+	    *dp++ = '\t';
+	    ocol += tw;
+	    ocol -= ocol % tw;
+	  }
+	while (ocol < dcol)
+	  {
+	    *dp++ = ' ';
+	    ocol++;
+	  }
+	*dp++ = *sp;
+	if (*sp == '\0')
+	  return;
+	++ocol;
+	++dcol;
       }
-      while (ocol < dcol) {
-        *dp++ = ' ';
-        ocol++;
-      }
-      *dp++ = *sp;
-      if (*sp == '\0')
-        return;
-      ++ocol;
-      ++dcol;
-    }
 }
 
 /*
@@ -218,17 +236,19 @@ void tabify_string(char *dest, char *src, size_t scol, size_t tw)
  * The output buffer should be big enough to contain the expanded string.
  * To be sure, sizeof(dest) should be >= strlen(src)*tw + 1.
  */
-void untabify_string(char *dest, char *src, size_t scol, size_t tw)
+void
+untabify_string (char *dest, char *src, size_t scol, size_t tw)
 {
   char *sp, *dp;
   int col = scol;
 
   for (sp = src, dp = dest; *sp != '\0'; ++sp)
-    if (*sp == '\t') {
-      do
-        *dp++ = ' ', ++col;
-      while ((col%tw) > 0);
-    }
+    if (*sp == '\t')
+      {
+	do
+	  *dp++ = ' ', ++col;
+	while ((col % tw) > 0);
+      }
     else
       *dp++ = *sp, ++col;
   *dp = '\0';
@@ -237,23 +257,24 @@ void untabify_string(char *dest, char *src, size_t scol, size_t tw)
 /*
  * Jump to the specified line number and offset.
  */
-void goto_point(Point pt)
+void
+goto_point (Point pt)
 {
   if (cur_bp->pt.n > pt.n)
     do
-      FUNCALL(previous_line);
+      FUNCALL (previous_line);
     while (cur_bp->pt.n > pt.n);
   else if (cur_bp->pt.n < pt.n)
     do
-      FUNCALL(next_line);
+      FUNCALL (next_line);
     while (cur_bp->pt.n < pt.n);
 
   if (cur_bp->pt.o > pt.o)
     do
-      FUNCALL(backward_char);
+      FUNCALL (backward_char);
     while (cur_bp->pt.o > pt.o);
   else if (cur_bp->pt.o < pt.o)
     do
-      FUNCALL(forward_char);
+      FUNCALL (forward_char);
     while (cur_bp->pt.o < pt.o);
 }
