@@ -1,6 +1,5 @@
 /* Circular doubly-linked lists/queues
-   Copyright (c) 1997-2005 Reuben Thomas.
-   All rights reserved.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Reuben Thomas.  All rights reserved.
 
    This file is part of Zile.
 
@@ -26,22 +25,23 @@
 
 
 typedef struct list_s *list;
-struct list_s {
+struct list_s
+{
   list prev;
   list next;
   void *item;
 };
 
-list list_new(void);
-void list_delete(list l);
-size_t list_length(list l);
-list list_prepend(list l, void *i);
-list list_append(list l, void *i);
-void *list_head(list l);
-void *list_behead(list l);
-void *list_betail(list l);
-void *list_at(list l, size_t n);
-void list_sort(list l, int (*cmp)(const void *p1, const void *p2));
+list list_new (void);
+void list_delete (list l);
+size_t list_length (list l);
+list list_prepend (list l, void *i);
+list list_append (list l, void *i);
+void *list_head (list l);
+void *list_behead (list l);
+void *list_betail (list l);
+void *list_at (list l, size_t n);
+void list_sort (list l, int (*cmp) (const void *p1, const void *p2));
 
 #define list_first(l) ((l)->next)
 #define list_last(l)  ((l)->prev)
