@@ -25,7 +25,8 @@
 
 #include "astr.h"
 
-typedef struct le {
+struct le
+{
   /* either data or a branch */
   struct le *branch;
   char *data;
@@ -35,26 +36,27 @@ typedef struct le {
   /* for the next in the list in the current parenlevel */
   struct le *list_prev;
   struct le *list_next;
-} le;
+};
+typedef struct le le;
 
-le *leNew(const char *text);
-void leReallyWipe(le *list);
-void leWipe(le *list);
+le *leNew (const char *text);
+void leReallyWipe (le * list);
+void leWipe (le * list);
 
-le *leAddHead(le *list, le *element);
-le *leAddTail(le *list, le *element);
+le *leAddHead (le * list, le * element);
+le *leAddTail (le * list, le * element);
 
-le *leAddBranchElement(le *list, le *branch, int quoted);
-le *leAddDataElement(le *list, const char *data, int quoted);
-le *leDup(le *list);
+le *leAddBranchElement (le * list, le * branch, int quoted);
+le *leAddDataElement (le * list, const char *data, int quoted);
+le *leDup (le * list);
 
-void leClearTag(le *list);
-void leTagData(le *list, char *data, int tagval);
-void leTagReplace(le *list, int tagval, le *newinfo);
+void leClearTag (le * list);
+void leTagData (le * list, char *data, int tagval);
+void leTagReplace (le * list, int tagval, le * newinfo);
 
-astr leDump(le *list, int indent);
-astr leDumpEval(le *list, int indent);
-astr leDumpEvalTree(le *list, int indent);
-astr leDumpReformat(le *tree);
+astr leDump (le * list, int indent);
+astr leDumpEval (le * list, int indent);
+astr leDumpEvalTree (le * list, int indent);
+astr leDumpReformat (le * tree);
 
 #endif
