@@ -18,96 +18,104 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: point.c,v 1.12 2005/09/22 21:21:33 rrt Exp $	*/
-
 #include "config.h"
 
 #include "zile.h"
 #include "extern.h"
 
-Point make_point(size_t lineno, size_t offset)
+Point
+make_point (size_t lineno, size_t offset)
 {
   Point pt;
-  pt.p = list_next(cur_bp->lines);
+  pt.p = list_next (cur_bp->lines);
   pt.n = lineno;
   pt.o = offset;
-  while (lineno > 0) {
-    pt.p = list_next(pt.p);
-    lineno--;
-  }
+  while (lineno > 0)
+    {
+      pt.p = list_next (pt.p);
+      lineno--;
+    }
   return pt;
 }
 
-int cmp_point(Point pt1, Point pt2)
+int
+cmp_point (Point pt1, Point pt2)
 {
   if (pt1.n < pt2.n)
     return -1;
   else if (pt1.n > pt2.n)
     return +1;
   else
-    return ((pt1.o < pt2.o) ? -1 :
-            (pt1.o > pt2.o) ? +1 : 0);
+    return ((pt1.o < pt2.o) ? -1 : (pt1.o > pt2.o) ? +1 : 0);
 }
 
-int point_dist(Point pt1, Point pt2)
+int
+point_dist (Point pt1, Point pt2)
 {
   int size = 0;
   Line *lp;
 
-  if (cmp_point(pt1, pt2) > 0)
-    swap_point(&pt1, &pt2);
+  if (cmp_point (pt1, pt2) > 0)
+    swap_point (&pt1, &pt2);
 
-  for (lp = pt1.p; ; lp = list_next(lp)) {
-    size += astr_len(lp->item);
+  for (lp = pt1.p;; lp = list_next (lp))
+    {
+      size += astr_len (lp->item);
 
-    if (lp == pt1.p)
-      size -= pt1.o;
+      if (lp == pt1.p)
+	size -= pt1.o;
 
-    if (lp == pt2.p) {
-      size -= astr_len(lp->item) - pt2.o;
-      break;
+      if (lp == pt2.p)
+	{
+	  size -= astr_len (lp->item) - pt2.o;
+	  break;
+	}
+      else
+	size++;
     }
-    else
-      size++;
-  }
 
   return size;
 }
 
-int count_lines(Point pt1, Point pt2)
+int
+count_lines (Point pt1, Point pt2)
 {
-  if (cmp_point(pt1, pt2) > 0)
-    swap_point(&pt1, &pt2);
+  if (cmp_point (pt1, pt2) > 0)
+    swap_point (&pt1, &pt2);
 
   return pt2.n - pt1.n;
 }
 
-void swap_point(Point *pt1, Point *pt2)
+void
+swap_point (Point * pt1, Point * pt2)
 {
   Point pt0 = *pt1;
   *pt1 = *pt2;
   *pt2 = pt0;
 }
 
-Point point_min(void)
+Point
+point_min (void)
 {
   Point pt;
-  pt.p = list_next(cur_bp->lines);
+  pt.p = list_next (cur_bp->lines);
   pt.n = 0;
   pt.o = 0;
   return pt;
 }
 
-Point point_max(void)
+Point
+point_max (void)
 {
   Point pt;
-  pt.p = list_prev(cur_bp->lines);
+  pt.p = list_prev (cur_bp->lines);
   pt.n = cur_bp->num_lines;
-  pt.o = astr_len(list_prev(cur_bp->lines)->item);
+  pt.o = astr_len (list_prev (cur_bp->lines)->item);
   return pt;
 }
 
-Point line_beginning_position(int count)
+Point
+line_beginning_position (int count)
 {
   Point pt;
 
@@ -117,17 +125,18 @@ Point line_beginning_position(int count)
   pt.o = 0;
 
   count--;
-  for (; count < 0 && list_prev(pt.p) != cur_bp->lines; pt.n--, count++)
-      pt.p = list_prev(pt.p);
-  for (; count > 0 && list_next(pt.p) != cur_bp->lines; pt.n++, count--)
-      pt.p = list_next(pt.p);
+  for (; count < 0 && list_prev (pt.p) != cur_bp->lines; pt.n--, count++)
+    pt.p = list_prev (pt.p);
+  for (; count > 0 && list_next (pt.p) != cur_bp->lines; pt.n++, count--)
+    pt.p = list_next (pt.p);
 
   return pt;
 }
 
-Point line_end_position(int count)
+Point
+line_end_position (int count)
 {
-  Point pt = line_beginning_position(count);
-  pt.o = astr_len(pt.p->item);
+  Point pt = line_beginning_position (count);
+  pt.o = astr_len (pt.p->item);
   return pt;
 }
