@@ -1,5 +1,5 @@
 /* Terminal independent redisplay routines
-   Copyright (c) 1997-2004 Sandro Sigala.  All rights reserved.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Sandro Sigala.  All rights reserved.
 
    This file is part of Zile.
 
@@ -24,72 +24,84 @@
 #include "zile.h"
 #include "extern.h"
 
-void resync_redisplay(void)
+void
+resync_redisplay (void)
 {
   int delta = cur_bp->pt.n - cur_wp->lastpointn;
 
-  if (delta) {
-    if ((delta > 0 && cur_wp->topdelta + delta < cur_wp->eheight) ||
-        (delta < 0 && cur_wp->topdelta >= (size_t)(-delta)))
-      cur_wp->topdelta += delta;
-    else if (cur_bp->pt.n > cur_wp->eheight / 2)
-      cur_wp->topdelta = cur_wp->eheight / 2;
-    else
-      cur_wp->topdelta = cur_bp->pt.n;
-  }
+  if (delta)
+    {
+      if ((delta > 0 && cur_wp->topdelta + delta < cur_wp->eheight) ||
+	  (delta < 0 && cur_wp->topdelta >= (size_t) (-delta)))
+	cur_wp->topdelta += delta;
+      else if (cur_bp->pt.n > cur_wp->eheight / 2)
+	cur_wp->topdelta = cur_wp->eheight / 2;
+      else
+	cur_wp->topdelta = cur_bp->pt.n;
+    }
   cur_wp->lastpointn = cur_bp->pt.n;
 }
 
-void resize_windows(void)
+void
+resize_windows (void)
 {
   Window *wp;
   int hdelta;
 
   /* Resize windows horizontally. */
   for (wp = head_wp; wp != NULL; wp = wp->next)
-    wp->fwidth = wp->ewidth = term_width();
+    wp->fwidth = wp->ewidth = term_width ();
 
   /* Work out difference in window height; windows may be taller than
      terminal if the terminal was very short. */
-  for (hdelta = term_height() - 1, wp = head_wp;
-       wp != NULL;
-       hdelta -= wp->fheight, wp = wp->next);
+  for (hdelta = term_height () - 1, wp = head_wp;
+       wp != NULL; hdelta -= wp->fheight, wp = wp->next);
 
   /* Resize windows vertically. */
-  if (hdelta > 0) { /* Increase windows height. */
-    for (wp = head_wp; hdelta > 0; wp = wp->next) {
-      if (wp == NULL)
-        wp = head_wp;
-      ++wp->fheight;
-      ++wp->eheight;
-      --hdelta;
+  if (hdelta > 0)
+    {				/* Increase windows height. */
+      for (wp = head_wp; hdelta > 0; wp = wp->next)
+	{
+	  if (wp == NULL)
+	    wp = head_wp;
+	  ++wp->fheight;
+	  ++wp->eheight;
+	  --hdelta;
+	}
     }
-  } else { /* Decrease windows' height, and close windows if necessary. */
-    int decreased = TRUE;
-    while (decreased) {
-      decreased = FALSE;
-      for (wp = head_wp; wp != NULL && hdelta < 0; wp = wp->next) {
-        if (wp->fheight > 2) {
-          --wp->fheight;
-          --wp->eheight;
-          ++hdelta;
-          decreased = TRUE;
-        } else if (cur_wp != head_wp || cur_wp->next != NULL) {
-          Window *new_wp = wp->next;
-          delete_window(wp);
-          wp = new_wp;
-          decreased = TRUE;
-        }
-      }
+  else
+    {				/* Decrease windows' height, and close windows if necessary. */
+      int decreased = TRUE;
+      while (decreased)
+	{
+	  decreased = FALSE;
+	  for (wp = head_wp; wp != NULL && hdelta < 0; wp = wp->next)
+	    {
+	      if (wp->fheight > 2)
+		{
+		  --wp->fheight;
+		  --wp->eheight;
+		  ++hdelta;
+		  decreased = TRUE;
+		}
+	      else if (cur_wp != head_wp || cur_wp->next != NULL)
+		{
+		  Window *new_wp = wp->next;
+		  delete_window (wp);
+		  wp = new_wp;
+		  decreased = TRUE;
+		}
+	    }
+	}
     }
-  }
 
-  FUNCALL(recenter);
+  FUNCALL (recenter);
 }
 
-void recenter(Window *wp)
+void
+recenter (Window * wp)
 {
-  Point pt = window_pt(wp);
+  Point pt = window_pt (wp);
 
   if (pt.n > wp->eheight / 2)
     wp->topdelta = wp->eheight / 2;
@@ -97,14 +109,14 @@ void recenter(Window *wp)
     wp->topdelta = pt.n;
 }
 
-DEFUN("recenter", recenter)
+DEFUN ("recenter", recenter)
 /*+
 Center point in window and redisplay screen.
 The desired position of point is always relative to the current window.
 +*/
 {
-  recenter(cur_wp);
-  term_full_redisplay();
+  recenter (cur_wp);
+  term_full_redisplay ();
   return TRUE;
 }
 END_DEFUN
