@@ -32,76 +32,88 @@
 le *mainVarList = NULL;
 
 
-le *variableFind(le *varlist, char *key)
+le *
+variableFind (le * varlist, char *key)
 {
   if (varlist != NULL && key != NULL)
     for (; varlist; varlist = varlist->list_next)
-      if (!strcmp(key, varlist->data))
-        return varlist;
+      if (!strcmp (key, varlist->data))
+	return varlist;
 
   return NULL;
 }
 
-void variableSet(le **varlist, char *key, le *value)
+void
+variableSet (le ** varlist, char *key, le * value)
 {
-  if (key && value) {
-    le *temp = variableFind(*varlist, key);
+  if (key && value)
+    {
+      le *temp = variableFind (*varlist, key);
 
-    if (temp)
-      leWipe(temp->branch);
-    else {
-      temp = leNew(key);
-      *varlist = leAddHead(*varlist, temp);
+      if (temp)
+	leWipe (temp->branch);
+      else
+	{
+	  temp = leNew (key);
+	  *varlist = leAddHead (*varlist, temp);
+	}
+
+      temp->branch = leDup (value);
     }
-
-    temp->branch = leDup(value);
-  }
 }
 
-void variableSetString(le **varlist, char *key, char *value)
+void
+variableSetString (le ** varlist, char *key, char *value)
 {
-  if (key && value) {
-    le *temp = leNew(value);
-    variableSet(varlist, key, temp);
-    leWipe(temp);
-  }
+  if (key && value)
+    {
+      le *temp = leNew (value);
+      variableSet (varlist, key, temp);
+      leWipe (temp);
+    }
 }
 
-void variableSetNumber(le **varlist, char *key, int value)
+void
+variableSetNumber (le ** varlist, char *key, int value)
 {
   char *buf;
 
-  zasprintf(&buf, "%d", value);
-  variableSetString(varlist, key, buf);
-  free(buf);
+  zasprintf (&buf, "%d", value);
+  variableSetString (varlist, key, buf);
+  free (buf);
 }
 
-le *variableGet(le *varlist, char *key)
+le *
+variableGet (le * varlist, char *key)
 {
-  le *temp = variableFind(varlist, key);
+  le *temp = variableFind (varlist, key);
   return temp ? temp->branch : NULL;
 }
 
-char *variableGetString(le *varlist, char *key)
+char *
+variableGetString (le * varlist, char *key)
 {
-  le *temp = variableFind(varlist, key);
+  le *temp = variableFind (varlist, key);
   if (temp && temp->branch && temp->branch->data
-      && countNodes(temp->branch) == 1)
+      && countNodes (temp->branch) == 1)
     return temp->branch->data;
   return NULL;
 }
 
-astr variableDump(le *varlist)
+astr
+variableDump (le * varlist)
 {
-  astr as = astr_new();
+  astr as = astr_new ();
 
-  for (; varlist; varlist = varlist->list_next) {
-    if (varlist->branch) {
-      astr_afmt(as, "%s \t", varlist->data);
-      astr_cat_delete(as, leDumpReformat(varlist->branch));
-      astr_cat_char(as, '\n');
+  for (; varlist; varlist = varlist->list_next)
+    {
+      if (varlist->branch)
+	{
+	  astr_afmt (as, "%s \t", varlist->data);
+	  astr_cat_delete (as, leDumpReformat (varlist->branch));
+	  astr_cat_char (as, '\n');
+	}
     }
-  }
 
   return as;
 }
